@@ -276,14 +276,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_apigatewayv2
-import aws_cdk.aws_cognito
-import aws_cdk.aws_lambda
-import aws_cdk.core
-import constructs
+import aws_cdk.aws_apigatewayv2 as _aws_cdk_aws_apigatewayv2_4b54cf3e
+import aws_cdk.aws_cognito as _aws_cdk_aws_cognito_371ee794
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import aws_cdk.core as _aws_cdk_core_f4b25747
+import constructs as _constructs_77d1e7e8
 
 
-@jsii.implements(aws_cdk.aws_apigatewayv2.IHttpRouteAuthorizer)
+@jsii.implements(_aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRouteAuthorizer)
 class HttpIamAuthorizer(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.HttpIamAuthorizer",
@@ -325,9 +325,9 @@ class HttpIamAuthorizer(
     def bind(
         self,
         *,
-        route: aws_cdk.aws_apigatewayv2.IHttpRoute,
-        scope: constructs.Construct,
-    ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
+        route: _aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRoute,
+        scope: _constructs_77d1e7e8.Construct,
+    ) -> _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig:
         '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
@@ -335,14 +335,14 @@ class HttpIamAuthorizer(
 
         :stability: experimental
         '''
-        _options = aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerBindOptions(
+        _options = _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerBindOptions(
             route=route, scope=scope
         )
 
-        return typing.cast(aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [_options]))
+        return typing.cast(_aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [_options]))
 
 
-@jsii.implements(aws_cdk.aws_apigatewayv2.IHttpRouteAuthorizer)
+@jsii.implements(_aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRouteAuthorizer)
 class HttpJwtAuthorizer(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.HttpJwtAuthorizer",
@@ -392,16 +392,7 @@ class HttpJwtAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                jwt_issuer: builtins.str,
-                *,
-                jwt_audience: typing.Sequence[builtins.str],
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1e7937476312b23cc3a040c6e1a29b01ad6d8660d717a8b6612ebdb2368acd30)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument jwt_issuer", value=jwt_issuer, expected_type=type_hints["jwt_issuer"])
         props = HttpJwtAuthorizerProps(
@@ -416,9 +407,9 @@ class HttpJwtAuthorizer(
     def bind(
         self,
         *,
-        route: aws_cdk.aws_apigatewayv2.IHttpRoute,
-        scope: constructs.Construct,
-    ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
+        route: _aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRoute,
+        scope: _constructs_77d1e7e8.Construct,
+    ) -> _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig:
         '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
@@ -426,11 +417,11 @@ class HttpJwtAuthorizer(
 
         :stability: experimental
         '''
-        options = aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerBindOptions(
+        options = _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerBindOptions(
             route=route, scope=scope
         )
 
-        return typing.cast(aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
+        return typing.cast(_aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
 
 
 @jsii.data_type(
@@ -479,18 +470,11 @@ class HttpJwtAuthorizerProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                jwt_audience: typing.Sequence[builtins.str],
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__006bc46199bd8f5bb1842b02f0c941a543dfe861675fcbf7f8838053ddcc040e)
             check_type(argname="argument jwt_audience", value=jwt_audience, expected_type=type_hints["jwt_audience"])
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "jwt_audience": jwt_audience,
         }
         if authorizer_name is not None:
@@ -544,7 +528,7 @@ class HttpJwtAuthorizerProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_apigatewayv2.IHttpRouteAuthorizer)
+@jsii.implements(_aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRouteAuthorizer)
 class HttpLambdaAuthorizer(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.HttpLambdaAuthorizer",
@@ -579,12 +563,12 @@ class HttpLambdaAuthorizer(
     def __init__(
         self,
         id: builtins.str,
-        handler: aws_cdk.aws_lambda.IFunction,
+        handler: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
         response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
-        results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
+        results_cache_ttl: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
     ) -> None:
         '''(experimental) Initialize a lambda authorizer to be bound with HTTP route.
 
@@ -598,17 +582,7 @@ class HttpLambdaAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                handler: aws_cdk.aws_lambda.IFunction,
-                *,
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-                response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
-                results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__82934c32235b183e7e4cd56cb4ac2a009724a32d8ae6d1e947b4360ff2385ef3)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = HttpLambdaAuthorizerProps(
@@ -624,9 +598,9 @@ class HttpLambdaAuthorizer(
     def bind(
         self,
         *,
-        route: aws_cdk.aws_apigatewayv2.IHttpRoute,
-        scope: constructs.Construct,
-    ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
+        route: _aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRoute,
+        scope: _constructs_77d1e7e8.Construct,
+    ) -> _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig:
         '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
@@ -634,11 +608,11 @@ class HttpLambdaAuthorizer(
 
         :stability: experimental
         '''
-        options = aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerBindOptions(
+        options = _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerBindOptions(
             route=route, scope=scope
         )
 
-        return typing.cast(aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
+        return typing.cast(_aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
 
 
 @jsii.data_type(
@@ -658,7 +632,7 @@ class HttpLambdaAuthorizerProps:
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
         response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
-        results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
+        results_cache_ttl: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
     ) -> None:
         '''(experimental) Properties to initialize HttpTokenAuthorizer.
 
@@ -692,20 +666,12 @@ class HttpLambdaAuthorizerProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-                response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
-                results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2db0a9c5ba6693767a87ac6d0b36748a12b521e7f7f29ddf7d2fb8e1e8120611)
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
             check_type(argname="argument response_types", value=response_types, expected_type=type_hints["response_types"])
             check_type(argname="argument results_cache_ttl", value=results_cache_ttl, expected_type=type_hints["results_cache_ttl"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
@@ -753,7 +719,7 @@ class HttpLambdaAuthorizerProps:
         return typing.cast(typing.Optional[typing.List["HttpLambdaResponseType"]], result)
 
     @builtins.property
-    def results_cache_ttl(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def results_cache_ttl(self) -> typing.Optional[_aws_cdk_core_f4b25747.Duration]:
         '''(experimental) How long APIGateway should cache the results.
 
         Max 1 hour.
@@ -764,7 +730,7 @@ class HttpLambdaAuthorizerProps:
         :stability: experimental
         '''
         result = self._values.get("results_cache_ttl")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[_aws_cdk_core_f4b25747.Duration], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -797,7 +763,7 @@ class HttpLambdaResponseType(enum.Enum):
     '''
 
 
-@jsii.implements(aws_cdk.aws_apigatewayv2.IHttpRouteAuthorizer)
+@jsii.implements(_aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRouteAuthorizer)
 class HttpUserPoolAuthorizer(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.HttpUserPoolAuthorizer",
@@ -830,11 +796,11 @@ class HttpUserPoolAuthorizer(
     def __init__(
         self,
         id: builtins.str,
-        pool: aws_cdk.aws_cognito.IUserPool,
+        pool: _aws_cdk_aws_cognito_371ee794.IUserPool,
         *,
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-        user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
+        user_pool_clients: typing.Optional[typing.Sequence[_aws_cdk_aws_cognito_371ee794.IUserPoolClient]] = None,
         user_pool_region: typing.Optional[builtins.str] = None,
     ) -> None:
         '''(experimental) Initialize a Cognito user pool authorizer to be bound with HTTP route.
@@ -849,17 +815,7 @@ class HttpUserPoolAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                pool: aws_cdk.aws_cognito.IUserPool,
-                *,
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-                user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
-                user_pool_region: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f160de5d787589b4c9a11bfa76a3f7e102b5fbb1e7c983857c9b2e1e27840e41)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument pool", value=pool, expected_type=type_hints["pool"])
         props = HttpUserPoolAuthorizerProps(
@@ -875,9 +831,9 @@ class HttpUserPoolAuthorizer(
     def bind(
         self,
         *,
-        route: aws_cdk.aws_apigatewayv2.IHttpRoute,
-        scope: constructs.Construct,
-    ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
+        route: _aws_cdk_aws_apigatewayv2_4b54cf3e.IHttpRoute,
+        scope: _constructs_77d1e7e8.Construct,
+    ) -> _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig:
         '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
@@ -885,11 +841,11 @@ class HttpUserPoolAuthorizer(
 
         :stability: experimental
         '''
-        options = aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerBindOptions(
+        options = _aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerBindOptions(
             route=route, scope=scope
         )
 
-        return typing.cast(aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
+        return typing.cast(_aws_cdk_aws_apigatewayv2_4b54cf3e.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
 
 
 @jsii.data_type(
@@ -908,7 +864,7 @@ class HttpUserPoolAuthorizerProps:
         *,
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-        user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
+        user_pool_clients: typing.Optional[typing.Sequence[_aws_cdk_aws_cognito_371ee794.IUserPoolClient]] = None,
         user_pool_region: typing.Optional[builtins.str] = None,
     ) -> None:
         '''(experimental) Properties to initialize HttpUserPoolAuthorizer.
@@ -938,20 +894,12 @@ class HttpUserPoolAuthorizerProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-                user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
-                user_pool_region: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e8f781070d5cd9aa6a9f11f467345d36183ec1d35eed5c0865c64838de6d47f8)
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
             check_type(argname="argument user_pool_clients", value=user_pool_clients, expected_type=type_hints["user_pool_clients"])
             check_type(argname="argument user_pool_region", value=user_pool_region, expected_type=type_hints["user_pool_region"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
@@ -986,7 +934,7 @@ class HttpUserPoolAuthorizerProps:
     @builtins.property
     def user_pool_clients(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cognito.IUserPoolClient]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cognito_371ee794.IUserPoolClient]]:
         '''(experimental) The user pool clients that should be used to authorize requests with the user pool.
 
         :default: - a new client will be created for the given user pool
@@ -994,7 +942,7 @@ class HttpUserPoolAuthorizerProps:
         :stability: experimental
         '''
         result = self._values.get("user_pool_clients")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cognito.IUserPoolClient]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cognito_371ee794.IUserPoolClient]], result)
 
     @builtins.property
     def user_pool_region(self) -> typing.Optional[builtins.str]:
@@ -1019,7 +967,7 @@ class HttpUserPoolAuthorizerProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_apigatewayv2.IWebSocketRouteAuthorizer)
+@jsii.implements(_aws_cdk_aws_apigatewayv2_4b54cf3e.IWebSocketRouteAuthorizer)
 class WebSocketLambdaAuthorizer(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.WebSocketLambdaAuthorizer",
@@ -1056,7 +1004,7 @@ class WebSocketLambdaAuthorizer(
     def __init__(
         self,
         id: builtins.str,
-        handler: aws_cdk.aws_lambda.IFunction,
+        handler: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -1070,15 +1018,7 @@ class WebSocketLambdaAuthorizer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                id: builtins.str,
-                handler: aws_cdk.aws_lambda.IFunction,
-                *,
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__52d16a0087a382a60482cf0515fede6ad0c3f01d1c6436fab2dac63062f36737)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = WebSocketLambdaAuthorizerProps(
@@ -1091,9 +1031,9 @@ class WebSocketLambdaAuthorizer(
     def bind(
         self,
         *,
-        route: aws_cdk.aws_apigatewayv2.IWebSocketRoute,
-        scope: constructs.Construct,
-    ) -> aws_cdk.aws_apigatewayv2.WebSocketRouteAuthorizerConfig:
+        route: _aws_cdk_aws_apigatewayv2_4b54cf3e.IWebSocketRoute,
+        scope: _constructs_77d1e7e8.Construct,
+    ) -> _aws_cdk_aws_apigatewayv2_4b54cf3e.WebSocketRouteAuthorizerConfig:
         '''(experimental) Bind this authorizer to a specified WebSocket route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
@@ -1101,11 +1041,11 @@ class WebSocketLambdaAuthorizer(
 
         :stability: experimental
         '''
-        options = aws_cdk.aws_apigatewayv2.WebSocketRouteAuthorizerBindOptions(
+        options = _aws_cdk_aws_apigatewayv2_4b54cf3e.WebSocketRouteAuthorizerBindOptions(
             route=route, scope=scope
         )
 
-        return typing.cast(aws_cdk.aws_apigatewayv2.WebSocketRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
+        return typing.cast(_aws_cdk_aws_apigatewayv2_4b54cf3e.WebSocketRouteAuthorizerConfig, jsii.invoke(self, "bind", [options]))
 
 
 @jsii.data_type(
@@ -1143,16 +1083,10 @@ class WebSocketLambdaAuthorizerProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                authorizer_name: typing.Optional[builtins.str] = None,
-                identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__311c5c3b54b28940e9ce0feb46cd87b8954a095f21a9800a4397c0c9c712fde1)
             check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
             check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
@@ -1210,3 +1144,85 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__1e7937476312b23cc3a040c6e1a29b01ad6d8660d717a8b6612ebdb2368acd30(
+    id: builtins.str,
+    jwt_issuer: builtins.str,
+    *,
+    jwt_audience: typing.Sequence[builtins.str],
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__006bc46199bd8f5bb1842b02f0c941a543dfe861675fcbf7f8838053ddcc040e(
+    *,
+    jwt_audience: typing.Sequence[builtins.str],
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__82934c32235b183e7e4cd56cb4ac2a009724a32d8ae6d1e947b4360ff2385ef3(
+    id: builtins.str,
+    handler: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
+    results_cache_ttl: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2db0a9c5ba6693767a87ac6d0b36748a12b521e7f7f29ddf7d2fb8e1e8120611(
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
+    results_cache_ttl: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f160de5d787589b4c9a11bfa76a3f7e102b5fbb1e7c983857c9b2e1e27840e41(
+    id: builtins.str,
+    pool: _aws_cdk_aws_cognito_371ee794.IUserPool,
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    user_pool_clients: typing.Optional[typing.Sequence[_aws_cdk_aws_cognito_371ee794.IUserPoolClient]] = None,
+    user_pool_region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e8f781070d5cd9aa6a9f11f467345d36183ec1d35eed5c0865c64838de6d47f8(
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    user_pool_clients: typing.Optional[typing.Sequence[_aws_cdk_aws_cognito_371ee794.IUserPoolClient]] = None,
+    user_pool_region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__52d16a0087a382a60482cf0515fede6ad0c3f01d1c6436fab2dac63062f36737(
+    id: builtins.str,
+    handler: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__311c5c3b54b28940e9ce0feb46cd87b8954a095f21a9800a4397c0c9c712fde1(
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
